pub struct GetImageList {
pub kind: LVSIL,
}Available on crate features
user and comctl only.Expand description
LVM_GETIMAGELIST
message parameters.
Return type: Option<HIMAGELIST>.
Fields
kind: LVSILTrait Implementations
Sourceimpl MsgSend for GetImageList
impl MsgSend for GetImageList
Sourcetype RetType = Option<HIMAGELIST>
type RetType = Option<HIMAGELIST>
Available on crate feature
user only.The specific type of the value returned by the message.
Sourceunsafe fn isize_to_ret(&self, v: isize) -> Self::RetType
unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType
Available on crate feature
user only.Unmarshaling method which converts the generic
isize return value to
the specific type returned by the message. Read moreSourcefn as_generic_wm(&mut self) -> WndMsg
fn as_generic_wm(&mut self) -> WndMsg
Available on crate feature
user only.Marshaling method which converts the specific message parameters struct
into the generic
WndMsg message struct.Auto Trait Implementations
impl Freeze for GetImageList
impl RefUnwindSafe for GetImageList
impl Send for GetImageList
impl Sync for GetImageList
impl Unpin for GetImageList
impl UnwindSafe for GetImageList